// Copyright (c) 2003-2010 Christopher M. Kohlhoff
// Modifications (c) 2011 by Guilherme Maciel Ferreira / Intra2net AG
//
// Distributed under the Boost Software License, Version 1.0.
//    (See accompanying file LICENSE_1_0.txt or copy at
//          http://www.boost.org/LICENSE_1_0.txt)
#include "icmp/icmpechoreplymessage.h"

#include <cstddef>

using namespace std;

//-----------------------------------------------------------------------------
// IcmpEchoReplyMessage
//-----------------------------------------------------------------------------

static const size_t MessageSizeInBytes = 8;

IcmpEchoReplyMessage::IcmpEchoReplyMessage() :
    Payload( MessageSizeInBytes )
{
}

IcmpEchoReplyMessage::~IcmpEchoReplyMessage()
{
}

Icmpv4Type IcmpEchoReplyMessage::get_type_v4() const
{
    Icmpv4Type type = static_cast<Icmpv4Type>( Payload[ 0 ] );

    return type;
}

void IcmpEchoReplyMessage::set_type_v4( const Icmpv4Type type )
{
    uint8_t n = static_cast<uint8_t>( type );

    Payload[ 0 ] = n;
}

Icmpv6Type IcmpEchoReplyMessage::get_type_v6() const
{
    Icmpv6Type type = static_cast<Icmpv6Type>( Payload[ 0 ] );

    return type;
}

void IcmpEchoReplyMessage::set_type_v6( const Icmpv6Type type )
{
    uint8_t n = static_cast<uint8_t>( type );

    Payload[ 0 ] = n;
}

uint8_t IcmpEchoReplyMessage::get_code() const
{
    return Payload[ 1 ];
}

void IcmpEchoReplyMessage::set_code( uint8_t code )
{
    Payload[ 1 ] = code;
}

uint16_t IcmpEchoReplyMessage::get_checksum() const
{
    return Payload.decode16( 2, 3 );
}

void IcmpEchoReplyMessage::set_checksum( uint16_t checksum )
{
    Payload.encode16( 2, 3, checksum );
}

uint16_t IcmpEchoReplyMessage::get_identifier() const
{
    return Payload.decode16( 4, 5 );
}

void IcmpEchoReplyMessage::set_identifier(
        const uint16_t identifier
)
{
    Payload.encode16( 4, 5, identifier );
}

uint16_t IcmpEchoReplyMessage::get_sequence_number() const
{
    return Payload.decode16( 6, 7 );
}

void IcmpEchoReplyMessage::set_sequence_number(
        const uint16_t sequence_number
)
{
    Payload.encode16( 6, 7, sequence_number );
}

std::istream& IcmpEchoReplyMessage::read( std::istream &is )
{
    return Payload.read( is );
}

std::ostream& IcmpEchoReplyMessage::write( std::ostream &os ) const
{
    return Payload.write( os );
}
